@@ -21,7 +21,7 @@
 #include <math.h>
 #include "crinkle.h"
 
-char calcalt_Id[] = "$Id: calcalt.c,v 2.18 2009/08/28 09:09:17 spb Exp spb $";
+char calcalt_Id[] = "$Id: calcalt.c,v 2.18 2009/08/28 09:09:17 spb Exp $";
 
 #ifdef DEBUG
 #define DB(A,B) dump_pipeline(A,B)
@@ -31,12 +31,7 @@ char calcalt_Id[] = "$Id: calcalt.c,v 2.18 2009/08/28 09:09:17 spb Exp spb $";
 
 
 /* {{{   Strip *make_strip(Fold *f) */
-#ifdef ANSI
-  Strip *make_strip(Fold *f) 
-#else
-Strip *make_strip (f)
-Fold *f;
-#endif
+Strip *make_strip(Fold *f) 
 {
   Strip *p;
   int n;
@@ -60,12 +55,7 @@ Fold *f;
 
 /* }}} */
 /* {{{   void free_strip(Strip *p) */
-#ifdef ANSI
 void free_strip(Strip *p) 
-#else
-void free_strip (p)
-Strip *p;
-#endif
 {
   if( p->d )
   {
@@ -76,12 +66,7 @@ Strip *p;
 }
 /* }}} */
 /* {{{   Strip *double_strip(Strip *s) */
-#ifdef ANSI
 Strip *double_strip(Strip *s) 
-#else
-Strip *double_strip (s)
-Strip *s;
-#endif
 {
   Strip *p;
   Height *a, *b;
@@ -105,13 +90,7 @@ Strip *s;
 }
 /* }}} */
 /* {{{   Strip *set_strip(Fold *f, Height value)*/
-#ifdef ANSI
 Strip *set_strip(Fold *f, Height value)
-#else
-Strip *set_strip (f,value)
-Fold *f;
-Height value;
-#endif
 {
   int i;
   Strip *s;
@@ -131,12 +110,7 @@ Height value;
 
 /* }}} */
 /* {{{   Strip *random_strip(Fold *f)*/
-#ifdef ANSI
 Strip *random_strip(Fold *f)
-#else
-Strip *random_strip(f)
-Fold *f;
-#endif
 {
   Strip *result;
   int i, count;
@@ -152,12 +126,7 @@ Fold *f;
 /* }}} */
 
 /* {{{ void reset_fold(Fold *f) */
-#ifdef ANSI
 void reset_fold(Fold *f) 
-#else
-void reset_fold(f)
-Fold *f;
-#endif
 {
   /*
    * resets any cached values within the fold structure
@@ -195,16 +164,7 @@ Fold *f;
  *   len gets smaller as the level increases.
  * start, the starting height for a non-fractal start.
  */
-#ifdef ANSI
 Fold *make_fold(Fold *parent,Parm *param, int levels, int stop, Length length) 
-#else
-Fold *make_fold (parent,param,levels,stop,length)
-struct fold *parent;
-struct parm *param;
-int levels;
-int stop;
-Length length;
-#endif
 {
   Fold *p;
   int i;
@@ -247,12 +207,7 @@ Length length;
 }
 /* }}} */
 /* {{{   void free_fold(Fold *f) */
-#ifdef ANSI
 void free_fold(Fold *f) 
-#else
-void free_fold (f)
-Fold *f;
-#endif
 {
   int i;
   if( f->next ){
@@ -277,12 +232,7 @@ Fold *f;
 /* }}} */
 
 /* {{{   Strip *next_strip(Fold *fold) */
-#ifdef ANSI
 Strip *next_strip(Fold *fold) 
-#else
-Strip *next_strip (fold)
-Fold *fold;
-#endif
 {
   Strip *result=NULL;
   Strip *tmp;
@@ -468,17 +418,7 @@ Fold *fold;
 /* }}} */
 
 /* {{{ void x_update(Fold *fold,float scale, float mix, Strip *a, Strip *b, Strip *c)*/
-#ifdef ANSI
 void x_update(Fold *fold,float scale, float mix, Strip *a, Strip *b, Strip *c)
-#else
-void x_update(fold, scale, mix, a, b, c)
-Fold *fold;
-float scale;
-float mix;
-Strip *a;
-Strip *b;
-Strip *c;
-#endif
 {
   int i;
   int count=fold->count;
@@ -535,17 +475,7 @@ Strip *c;
 }    
 /* }}} */
 /* {{{ void p_update(Fold *fold,float scale, float mix, Strip *a, Strip *b, Strip *c)*/
-#ifdef ANSI
 void p_update(Fold *fold,float scale, float mix, Strip *a, Strip *b, Strip *c)
-#else
-void p_update(fold, scale, mix, a, b, c)
-Fold *fold;
-float scale;
-float mix;
-Strip *a;
-Strip *b;
-Strip *c;
-#endif
 {
   int i;
   int count=fold->count;
@@ -608,17 +538,7 @@ Strip *c;
 
 /* }}} */
 /* {{{ void t_update(Fold *fold,float scale, float mix, Strip *a, Strip *b, Strip *c)*/
-#ifdef ANSI
 void t_update(Fold *fold,float scale, float mix, Strip *a, Strip *b, Strip *c)
-#else
-void t_update(fold, scale, mix, a, b, c)
-Fold *fold;
-float scale;
-float mix;
-Strip *a;
-Strip *b;
-Strip *c;
-#endif
 {
   int i;
   int count=fold->count;
@@ -693,17 +613,7 @@ Strip *c;
 
 /* }}} */
 /* {{{ void v_update(Fold *fold,float scale, float mix, Strip *a, Strip *b, Strip *c)*/
-#ifdef ANSI
 void v_update(Fold *fold,float scale, float mix, Strip *a, Strip *b, Strip *c)
-#else
-void v_update(fold, scale, mix, a, b, c)
-Fold *fold;
-float scale;
-float mix;
-Strip *a;
-Strip *b;
-Strip *c;
-#endif
 {
   int i;
   int count=fold->count;
@@ -776,15 +686,7 @@ Strip *c;
 
 /* }}} */
 /* {{{ void vside_update(Fold *fold,float scale, float mix, Strip *a)*/
-#ifdef ANSI
 void vside_update(Fold *fold,float scale, float mix, Strip *a)
-#else
-void vside_update(fold, scale, mix, a)
-Fold *fold;
-float scale;
-float mix;
-Strip *a;
-#endif
 {
   int i;
   int count=fold->count;
@@ -831,17 +733,7 @@ Strip *a;
 
 /* }}} */
 /* {{{ void hside_update(Fold *fold,float scale, float mix, Strip *a, Strip *b, Strip *c)*/
-#ifdef ANSI
 void hside_update(Fold *fold,float scale, float mix, Strip *a, Strip *b, Strip *c)
-#else
-void hside_update(fold, scale, mix, a, b, c)
-Fold *fold;
-float scale;
-float mix;
-Strip *a;
-Strip *b;
-Strip *c;
-#endif
 {
   int i;
   int count=fold->count;
@@ -903,9 +795,7 @@ Strip *c;
 
 
 #ifdef DEBUG
-dump_pipeline(s, f)
-char *s;
-Fold *f;
+dump_pipeline(char *s,Fold *f)
 {
   printf("%s[%d]: %0xd %0xd %0xd %0xd %0xd %0xd %0xd %0xd\n",s,f->level,
      f->s[0],f->s[1],f->s[2],f->s[3],f->s[4],f->s[5],f->s[6],f->s[7]);
