@@ -9,6 +9,9 @@
 #include "paint.h"
 #include "patchlevel.h"
 #include "copyright.h"
+#include<X11/Xlib.h>
+#include<X11/Xutil.h>
+#include<X11/Xatom.h>
 
 #define VERSION 2
 #define SIDE 1.0
@@ -78,26 +81,15 @@ int my_getopt (int argc, char **argv, char *pat)
 }
 /* }}} */
 
-double atof();
-#ifdef ANSI
 void init_graphics (int, Window, int,int, Graph *, Gun *, Gun *, Gun *);
 void clear_col( int );
 void finish_graphics();
 void plot_pixel (int, int, unsigned char);
 void scroll_screen ( int );
 void zap_events();
-#else
-void init_graphics ();
-void clear_col();
-void finish_graphics();
-void plot_pixel ();
-void scroll_screen ();
-void zap_events();
-#endif
 
-void finish_prog();
+void finish_prog(int err);
 
-int s_height=768, s_width=1024;
 int mapwid;
 
 /* Go through argv and find and extract any "-window-id NNNN" or
@@ -156,6 +148,8 @@ int main (int argc, char **argv)
   char *mesg[2];
   Gun *clut[3];
   FILE *pidfile;
+  struct sigaction sa;
+
   swosh = 0;          /* default is ! -w */
 
   init_parameters();
@@ -165,7 +159,7 @@ int main (int argc, char **argv)
 
   mesg[0]="false";
   mesg[1]="true";
-  while((c = my_getopt(argc,argv,"whbxmqMEHl:r:f:t:I:A:S:T:W:C:a:p:B:n:R:g:d:c:e:v:Z:s:X:Y:P:F:G:"))!= -1)
+  while((c = my_getopt(argc,argv,"whbxmqMEHl:r:f:t:I:A:S:T:W:C:a:p:B:n:R:g:d:c:e:v:Z:s:X:Y:P:F:G:K:L:"))!= -1)
   {
     switch(c){
        case 'w':
@@ -354,6 +348,19 @@ int main (int argc, char **argv)
       case 'd':
          display = optarg;
          break;
+      case 'K':
+	 g.graph_width = atoi( optarg );
+	 if( g.graph_width < 10 )
+	 {
+	   g.graph_width=1024;
+	 }
+	 break;
+      case 'L':
+	 g.graph_height = atoi( optarg );
+         if( g.graph_height < 10 ){
+	   g.graph_height = 768;
+	 }
+	 break;
       case 'H':
          print_algorithm();
          errflg++;
@@ -404,6 +411,8 @@ int main (int argc, char **argv)
     fprintf(stderr," -X float [%f] fraction of old value for rg2 & rg3\n",fold_param.mix);
     fprintf(stderr," -Y float [%f] fraction of old value for rg1\n",fold_param.midmix);
     fprintf(stderr," -window-id 0xNNNNN  draw on existing external window.\n");
+    fprintf(stderr," -K int [%d] width of window\n",g.graph_width);
+    fprintf(stderr," -L int [%d] height of window\n",g.graph_height);
     fprintf(stderr," -H            print short description of algorithm.\n");
     exit(1);
   }
@@ -430,26 +439,11 @@ int main (int argc, char **argv)
   seed_uni(seed);
 
   init_artist_variables();
-  if( SIG_ERR == signal(SIGINT, finish_prog ))
-  {
-    perror(argv[0]);
-    exit(1);
-  }
-  if( SIG_ERR == signal(SIGTERM, finish_prog ))
-  {
-    perror(argv[0]);
-    exit(1);
-  }
-  if( SIG_ERR == signal(SIGHUP, finish_prog ))
-  {
-    perror(argv[0]);
-    exit(1);
-  }
-  if( SIG_ERR == signal(SIGQUIT, finish_prog ))
-  {
-    perror(argv[0]);
-    exit(1);
-  }
+  sa.sa_handler = &finish_prog;
+  sigaction(SIGINT, &sa, NULL );
+  sigaction(SIGTERM, &sa, NULL );
+  sigaction(SIGHUP, &sa, NULL );
+  sigaction(SIGQUIT, &sa, NULL );
 
 
   /* This is a stand in for the event loop in a Widget set implementation 
@@ -483,7 +477,7 @@ int main (int argc, char **argv)
     
 extern int quit_xmount;
 
-void finish_prog()
+void finish_prog(int err)
 {
   /* The next time zap_events is called the program will quit */
   quit_xmount=TRUE;
